==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridCellEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditStartedEventArgsDescription } from "./GridCellEditStartedEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEditStartedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEditStartedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEditStartedEventArgsDescriptionMetadata.a == null) {
                GridCellEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEditStartedEventArgsDescriptionMetadata.c(GridCellEditStartedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridCellEditStartedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridCellEditStartedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridCellEditStartedEventArgsDescriptionMetadata.b(a);
            a.ad("GridCellEditStartedEventArgs", () => new GridCellEditStartedEventArgsDescription());
            a.ac("GridCellEditStartedEventArgs", GridCellEditStartedEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEditStartedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellEditStartedEventArgsDescriptionMetadata, 'GridCellEditStartedEventArgsDescriptionMetadata');
    GridCellEditStartedEventArgsDescriptionMetadata.a = null;
    return GridCellEditStartedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/GridCellEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditStartedEventArgsDescription } from "./GridCellEditStartedEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEditStartedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEditStartedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEditStartedEventArgsDescriptionMetadata.a == null) {
                GridCellEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEditStartedEventArgsDescriptionMetadata.c(GridCellEditStartedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridCellEditStartedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridCellEditStartedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridCellEditStartedEventArgsDescriptionMetadata.b(a);
            a.ae("GridCellEditStartedEventArgs", () => new GridCellEditStartedEventArgsDescription());
            a.ad("GridCellEditStartedEventArgs", GridCellEditStartedEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEditStartedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellEditStartedEventArgsDescriptionMetadata, 'GridCellEditStartedEventArgsDescriptionMetadata');
    GridCellEditStartedEventArgsDescriptionMetadata.a = null;
    return GridCellEditStartedEventArgsDescriptionMetadata;
})();
